-- main.lua
-- ****** Comment *****************************************************
-- Revision: 1.0
-- Issued  : mar.5, 2025
-- Auther  : Tanzai
-- Contents: This script controlls a plugin, "H6K_On-board_Walk" on X-Plane 12.
--           This Plugin shall be stored in /plugins/ folder under airplane
--           H6K Airliner 4.0.
-- Notice 1: This script may be redistributed for non commercial purposes
--           only; derivatives MAY NOT be redistributed.
-- Notice 2: Do not resize X-Plane window during flight to prevent incorrrect
--           display. You can restore the window by pressing a menu 
--           "Reload theCurrent Airplane (Skip Art Reload)" under "Developer".
-- *******************************************************************

setAircraftPanelRendering(false)
set3DRendering(false)
setInteractivity(false)

-- Subwindow setting  ------------------------------------------
winW = globalPropertyi("sim/graphics/view/window_width")
-- winH = globalPropertyi("sim/graphics/view/window_height")
local popup = contextWindow {
	position 		= {(get(winW)/2 - 80), 0, 160, 100},
	noResize 		= true,
	visible 		= true,
	noBackground 	= true,
	layer			= SASL_CW_LAYER_FLOATING_WINDOWS,
	noDecore 		= true,
	noMove 			= true,
	components 		= {MouseClick{position={0, 0, 160, 100},},},
					  }

-- Pilot head down 7 deg  ------------------------------------------
PilotHeadThe = globalPropertyf("sim/graphics/view/pilots_head_the")
function onModuleInit ()
	set( PilotHeadThe, -7)
end

function onAirportLoaded()
	set( PilotHeadThe, -7)
end

-- On-board walking  ------------------------------------------
isExternal = globalPropertyi("sim/graphics/view/view_is_external")
HeadX = globalPropertyf("sim/graphics/view/pilots_head_x")
HeadY = globalPropertyf("sim/graphics/view/pilots_head_y")
HeadZ = globalPropertyf("sim/graphics/view/pilots_head_z")
HeadThe = globalPropertyf("sim/graphics/view/pilots_head_the") -- Pilots pitch
HeadPsi = globalPropertyf("sim/graphics/view/pilots_head_psi") -- Pilots heading
framePeriod = globalPropertyf("sim/operation/misc/frame_rate_period")
local curHeading = globalPropertyf("sim/cockpit2/gauges/indicators/compass_heading_deg_mag")
local headToFly = globalPropertyf("sim/cockpit2/autopilot/heading_dial_deg_mag_pilot")
local headMode = globalPropertyi("sim/cockpit2/autopilot/heading_mode") -- 12:free,16:hold
local curAlt = globalPropertyf("sim/cockpit2/gauges/indicators/altitude_ft_pilot")
local altToFly = globalPropertyf("sim/cockpit2/autopilot/altitude_dial_ft") -- deg
local altMode = globalPropertyi("sim/cockpit2/autopilot/altitude_mode") -- 12:free,6:hold
local AP_Ride = globalPropertyi("sim/operation/override/override_autopilot")
defineProperty("WalkerIsOn", 0)  -- 0:off 1:on
local headingHold = findCommand ( "sim/autopilot/heading_hold" )
local altitudeHold = findCommand ( "sim/autopilot/altitude_hold" )
iniHeadX = 0.52
iniHeadY = 0.58
iniHeadZ = -4.65
iniHeadPsi = 0
iniHeadThe = -7
state = 0
cycle = 0
defineProperty("TurnLeft", 0)      -- 0:現状保持 1:左回転開始
defineProperty("TurnRight", 0)     -- 0:現状保持 1:右回転開始
defineProperty("CurrHead", 0)      -- 0:正面向き 180:後方向き

function update()
	if get(isExternal) == 0 then
		if get(WalkerIsOn) == 0 then                  -- When WalkerIsOn = 0
			if get(HeadX) <= 0.1 then
				if cycle == 0 then
-- 					setAP()
					set(WalkerIsOn, 1)
					set(HeadX, 0)
					set(HeadY, iniHeadY)
-- 					set(HeadZ, iniHeadZ)
					set(HeadThe, 0)
					set(HeadPsi, get(CurrHead))
					cycle = 1
 				else
 					set(HeadX, 0)
				end
			end
		else                                          -- When WalkerIsOn = 1
			if get(HeadX) > 0.1 then
				set(WalkerIsOn, 0)
				cycle = 0
 			elseif get(HeadX) < 0.0 then
				set(HeadX, 0)
			end

			if get(TurnLeft) == 1 then
				state = math.min( 180, (state + 360*get(framePeriod)))
				if get(CurrHead) == 0 then
					set(HeadPsi, 360 - state)
					if state >= 180 then
						set(HeadPsi, 180)
						set(CurrHead, 180)
						set(TurnLeft, 0)
						state = 0
					end
				else
					set(HeadPsi, 180 - state)
					if state >= 180 then
						set(HeadPsi, 0)
						set(CurrHead, 0)
						set(TurnLeft, 0)
						state = 0
					end
				end
			end
		
			if get(TurnRight) == 1 then
				state = math.min( 180, (state + 360*get(framePeriod)))
				if get(CurrHead) == 0 then
					set(HeadPsi, state)
					if state >= 180 then
						set(HeadPsi, 180)
						set(CurrHead, 180)
						set(TurnRight, 0)
						state = 0
					end
				else
					set(HeadPsi, 180 + state)
					if state >= 180 then
						set(HeadPsi, 0)
						set(CurrHead, 0)
						set(TurnRight, 0)
						state = 0
					end
				end
			end
		end
	end
end

-- function setAP()                    -- Set AP to hold altitude and heading 
-- 	set(headToFly, get(curHeading))
-- 	sasl.commandOnce( headingHold )
-- 	sasl.commandOnce( altitudeHold )
-- end